==> vue-cell-2.8.0.tgz: package/lib/index.js <==
import { t } from "@dftvue2-opentiny/vue-locale";
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/cell/vue";
import { defineComponent, $prefix, setup as _setup } from "@dftvue2-opentiny/vue-common";
import { IconChevronRight } from "@dftvue2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Cell",
  componentName: "Cell",
  props: {
    placeholder: {
      type: String,
      default: t("ui.cell.placeholder")
    },
    disabled: {
      type: Boolean,
      default: false
    },
    data: {
      type: String,
      default: ""
    },
    icon: {
      type: [Object, String],
      default: function _default() {
        return IconChevronRight();
      }
    }
  },
  setup: function setup(props, context) {
    return _setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "border-0 border-color-border rounded relative w-full h-7 leading-7 sm:leading-6.5 pr-5 sm:pr-7 cursor-pointer line-clamp-1 pl-3",
    class: [_vm.m(_vm.data ? "text-color-text-primary" : "text-color-icon-placeholder", _vm.state.isDisplayOnly ? "pointer-events-none cursor-default text-color-text-primary pl-0" : "sm:border", _vm.state.isDisabled ? "bg-color-bg-4 cursor-not-allowed" : "")],
    attrs: {
      "data-tag": "tiny-cell"
    },
    on: {
      "click": function click($event) {
        _vm.state.isDisabled ? "" : _vm.$emit("click", $event);
      }
    }
  }, [_vm._v(" " + _vm._s(_vm.state.isDisplayOnly ? _vm.data || "-" : _vm.data || _vm.placeholder) + " "), !(_vm.state.isDisplayOnly || _vm.state.isDisabled) ? _c("div", {
    attrs: {
      "data-tag": "tiny-cell-icon"
    }
  }, [_vm._t("icon", function() {
    return [_c(_vm.icon, {
      tag: "component",
      staticClass: "h-4 w-4 absolute top-1.5 sm:top-1 right-0 sm:right-2 fill-color-icon-placeholder"
    })];
  })], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var Cell = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.8.0";
Cell.install = function(Vue) {
  Vue.component(Cell.name, Cell);
};
Cell.version = version;
export {
  Cell as default
};

==> vue-cell-2.21.0.tgz: package/lib/index.js <==
import { t } from '@opentinyvue/vue-locale';
import { renderless, api } from '@opentinyvue/vue-renderless/cell/vue';
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { IconChevronRight } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Cell",
  componentName: "Cell",
  props: {
    placeholder: {
      type: String,
      default: t("ui.cell.placeholder")
    },
    disabled: {
      type: Boolean,
      default: false
    },
    data: {
      type: String,
      default: ""
    },
    icon: {
      type: [Object, String],
      default: function _default() {
        return IconChevronRight();
      }
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "border-0 border-color-border rounded relative w-full h-7 leading-7 sm:leading-6.5 pr-5 sm:pr-7 pl-0 sm:pl-3 cursor-pointer line-clamp-1",
    class: [_vm.m(_vm.data ? "text-color-text-primary" : "text-color-icon-placeholder", _vm.state.isDisplayOnly ? "pointer-events-none cursor-default text-color-text-primary pl-0" : "sm:border", _vm.state.isDisabled ? "sm:bg-color-bg-4 cursor-not-allowed" : "")],
    attrs: {
      "data-tag": "tiny-cell"
    },
    on: {
      "click": function click($event) {
        _vm.state.isDisabled ? "" : _vm.$emit("click", $event);
      }
    }
  }, [_vm._v(" " + _vm._s(_vm.state.isDisplayOnly ? _vm.data || "-" : _vm.data || _vm.placeholder) + " "), !(_vm.state.isDisplayOnly || _vm.state.isDisabled) ? _c("div", {
    attrs: {
      "data-tag": "tiny-cell-icon"
    }
  }, [_vm._t("icon", function() {
    return [_c(_vm.icon, {
      tag: "component",
      staticClass: "h-4 w-4 absolute top-1.5 sm:top-1 right-0 sm:right-2 fill-color-icon-placeholder"
    })];
  })], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var Cell = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.21.0";
Cell.install = function(Vue) {
  Vue.component(Cell.name, Cell);
};
Cell.version = version;

export { Cell as default };
